@@ -11,12 +11,11 @@ Copyright © Semantyk 2020. All rights reserved.\
 '''
 
 __author__ = 'Daniel Bakas Amuchastegui'
-__date__ = '2020-05-21'
-__email__ = 'danielbakas@gmail.com'
-__version__ = '0.0.0.60'
+__date__ = '2017-08-31'
+__email__ = 'daniel@semantyk.com'
+__version__ = '0.0.0.67'
 
-from . import (archive, av_reality, core, das, dots, dvm, games, learn, sam,
-               store, tools, uuid_generator)
+from . import archive, av_reality, core, das, dots, dvm, games, learn, sam, store, tools, uuid_generator
 from .archive import *
 from .av_reality import *
 from .core import *
